@@ -73,6 +73,9 @@ class INPUT_SOURCE(Command):
     GET, SET = True, True
 
     class INPUT_SOURCE_STATE(Enum):
+        # not a valid value for INPUT_SOURCE, but valid for auto_source
+        NONE = 0x00
+
         S_VIDEO = 0x04
         COMPONENT = 0x08
         AV = 0x0C
@@ -154,12 +157,24 @@ class SCREEN_SIZE(Command):
     DATA = [Int('INCHES', range(256))]
 
 
+class MAGICINFO_SERVER(Command):
+    """
+    MagicInfo Server URL (example: "http://example.com:80")
+    """
+    CMD = 0x1C
+    SUBCMD = 0x82
+    GET, SET = True, True
+
+    DATA = [Str('MAGICINFO_SERVER_URL')]
+
+
 class MDC_CONNECTION(Command):
+    """
+    Note: Depends on the product specification,
+    if it is set as RJ45 then serial MDC will not work.
+    """
     CMD = 0x1D
-    GET, SET = True, False
-    # NOTE: There is no Set command in documentation,
-    # but comment states that this parameter is readonly
-    # only for RJ45 connection...
+    GET, SET = True, True
 
     class MDC_CONNECTION_TYPE(Enum):
         RS232C = 0x00
@@ -421,6 +436,9 @@ class DEVICE_NAME(Command):
 
 
 class OSD(Command):
+    """
+    Turns OSD (On-screen display) on/off.
+    """
     CMD = 0x70
     GET, SET = True, True
 
@@ -480,6 +498,9 @@ class RESET(Command):
 
 
 class OSD_TYPE(Command):
+    """
+    Turns OSD (On-screen display) specific message types on/off.
+    """
     CMD = 0xA3
     GET, SET = True, True
 
@@ -624,7 +645,7 @@ class VIRTUAL_REMOTE(Command):
     CMD = 0xB0
     GET, SET = False, True
 
-    class REMOTE_KEY_CODE(Enum):
+    class KEY_CODE(Enum):
         KEY_SOURCE = 0x01
         KEY_POWER = 0x02
         KEY_1 = 0x04
@@ -669,7 +690,19 @@ class VIRTUAL_REMOTE(Command):
         DISCRET_POWER_OFF = 0x98
         KEY_3D = 0x9F
 
-    DATA = [REMOTE_KEY_CODE]
+    # # Corresponding to MediaKey API
+    # # https://docs.tizen.org/application/web/api/latest/device_api/mobile/tizen/mediakey.html  # noqa
+    # class MEDIA_KEY_CODE(Enum):
+    #     PLAY = KEY_CODE.KEY_PLAY
+    #     STOP = KEY_CODE.KEY_STOP
+    #     PAUSE = KEY_CODE.KEY_PAUSE
+    #     # PREVIOUS = ??
+    #     # NEXT = ??
+    #     FAST_FORWARD = KEY_CODE.KEY_FF
+    #     REWIND - KEY_CODE.KEY_REW
+    #     # PLAY_PAUSE = ??
+
+    DATA = [KEY_CODE]
 
 
 class NETWORK_STANDBY(Command):
@@ -766,6 +799,34 @@ class DISPLAY_ID(Command):
     DATA = [DISPLAY_ID_STATE]
 
 
+class AUTO_SOURCE_SWITCH(Command):
+    CMD = 0xCA
+    SUBCMD = 0x81
+    GET, SET = True, True
+
+    class AUTO_SOURCE_SWITCH_STATE(Enum):
+        OFF = 0x00
+        ON = 0x01
+
+    DATA = [AUTO_SOURCE_SWITCH_STATE]
+
+
+class AUTO_SOURCE(Command):
+    CMD = 0xCA
+    SUBCMD = 0x82
+    GET, SET = True, True
+
+    class PRIMARY_SOURCE_RECOVERY(Enum):
+        OFF = 0x00
+        ON = 0x01
+
+    DATA = [
+        PRIMARY_SOURCE_RECOVERY,
+        EnumField(INPUT_SOURCE.INPUT_SOURCE_STATE, 'PRIMARY_SOURCE'),
+        EnumField(INPUT_SOURCE.INPUT_SOURCE_STATE, 'SECONDARY_SOURCE')
+    ]
+
+
 class LAUNCHER_PLAY_VIA(Command):
     CMD = 0xC7
     SUBCMD = 0x81
